<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="theme-color" content="#46b58c">
    <meta name="description" content="">
    <meta property="og:title" content="{Obj}">
    <meta property="og:image" content="">
    <meta property="og:description" content="">
    <meta property="og:url" content="">
    <meta name="twitter:card" content="summary_large_image">
    <title>{Obj}</title>

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0-beta1/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-0evHe/X+R7YkIZDRvuzKMRqM+OrBnVFBL6DOitfPri4tjfHxaWutUpFmBp4vmVor" crossorigin="anonymous">
    <link rel="stylesheet" href="{{{{ url_for('static', path='/css/stylesheet.css') }}}}">
    <link rel="shortcut icon" 
      type="image/png" 
      href="{{{{ url_for('static', path='/img/logo.svg') }}}}" />

  </head>
  <body>
    <nav class="navbar navbar-expand-lg navbar-light bg-light fixed-top shadow-sm">
        <div class="container px-4">
            <a class="navbar-brand fw-bold" href="/">
                <img src="{{{{ url_for('static', path='/img/logo.svg') }}}}" alt="" class="logo" width="30px" height="auto">
                {Obj}
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarResponsive" aria-controls="navbarResponsive" aria-expanded="false" aria-label="Toggle navigation">
                &#9776;
            </button>
            <div class="collapse navbar-collapse" id="navbarResponsive">
                <ul class="navbar-nav ms-auto me-4 my-3 my-lg-0">
                    <li class="nav-item">
                        <a class="nav-link me-lg-3" href="/">
                            Home
                        </a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
    {{% block content %}}
    {{% endblock %}}
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0-beta1/dist/js/bootstrap.bundle.min.js" integrity="sha384-pprn3073KE6tl6bjs2QrFaJGz5/SUsLqktiwsUTF55Jfv3qYSDhgCecCxMW52nD2" crossorigin="anonymous"></script>
  </body>
</html>